@@ -10,18 +10,20 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
-$DATE = '2003/07/03';
+$VERSION = '0.03';
+$DATE = '2003/09/13';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_Package.pm' => [qw(0.02 2003/07/03), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
-    'lib/File/Package.pm' => [qw(1.11 2003/07/03), 'revised 1.1'],
-    't/File/package.t' => [qw(0.08 2003/07/03), 'revised 0.07'],
+    'lib/Docs/Site_SVD/File_Package.pm' => [qw(0.03 2003/09/13), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2003/09/13), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2003/09/13), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2003/09/13), 'generated, replaces 0.02'],
+    'lib/File/Package.pm' => [qw(1.12 2003/09/13), 'revised 1.1'],
+    't/File/package.t' => [qw(0.09 2003/09/13), 'revised 0.08'],
+    't/File/BadLoad.pm' => [qw(0.01 2003/09/13), 'new'],
+    't/File/BadVocab.pm' => [qw(0.01 2003/09/13), 'new'],
 
 );
 
@@ -48,11 +50,11 @@ use vars qw(%INVENTORY);
 
   File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
 
- Revision: A
+ Revision: B
 
- Version: 0.02
+ Version: 0.03
 
- Date: 2003/07/03
+ Date: 2003/09/13
 
  Prepared for: General Public 
 
@@ -95,7 +97,7 @@ in failure report back to the author of the package.
 
 =head2 1.3 Document overview.
 
-This document releases File::Package version 0.02
+This document releases File::Package version 0.03
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -111,8 +113,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-Package-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.02
+   http://www.softwarediamonds/packages/File-Package-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.03
 
 
 Restrictions regarding duplication and license provisions
@@ -180,37 +182,32 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_Package.pm                            0.02    2003/07/03 revised 0.01
- MANIFEST                                                     0.02    2003/07/03 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/07/03 generated, replaces 0.01
- README                                                       0.02    2003/07/03 generated, replaces 0.01
- lib/File/Package.pm                                          1.11    2003/07/03 revised 1.1
- t/File/package.t                                             0.08    2003/07/03 revised 0.07
+ lib/Docs/Site_SVD/File_Package.pm                            0.03    2003/09/13 revised 0.02
+ MANIFEST                                                     0.03    2003/09/13 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2003/09/13 generated, replaces 0.02
+ README                                                       0.03    2003/09/13 generated, replaces 0.02
+ lib/File/Package.pm                                          1.12    2003/09/13 revised 1.1
+ t/File/package.t                                             0.09    2003/09/13 revised 0.08
+ t/File/BadLoad.pm                                            0.01    2003/09/13 new
+ t/File/BadVocab.pm                                           0.01    2003/09/13 new
 
 
 =head2 3.3 Changes
 
-The file names from 0.01 were changed as follows:
+The file names from 0.02 were changed as follows:
 
  return if $file =~ s=lib/File/FileUtil.pm=lib/File/Package.pm=;
  return if $file =~ s=t/File/FileUtil/FileUtil.t=t/File/package.t=;
 
-Removed the methods for loading a
-program module with the same name 
-from the "File::FileUtil" module to their own module
-"File::Package" module.
-The module name is now much more descriptive
-of the routines in the module.
-
 Changes to past revisions are as follows: 
 
 =over 4
 
-=item Test::TestUtil 0.01
+=item Test-TestUtil-0.01
 
 Originated
 
-=item Test::TestUtil 0.02
+=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -235,7 +232,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-=item Test::TestUtil 0.03
+=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -265,7 +262,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-=item Test::TestUtil 0.04
+=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -295,7 +292,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
   File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
 
 
- Revision: A
+ Revision: B
 
 [snip]
 
@@ -330,7 +327,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-=item File::FileUtil 0.01
+=item File-FileUtil-0.01
 
 =over 4
 
@@ -385,11 +382,11 @@ failure from CPAN testing whose is running on a different platform.
 
 =back
 
-=item File::FileUtil 0.02
+=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-=item File::FileUtil 0.03
+=item File-FileUtil-0.03
 
 =over 4
 
@@ -408,21 +405,32 @@ the directories in @INC
 
 =back
 
+=item File-Package-0.01
+
+Removed the methods for loading a
+program module with the same name 
+from the "File::FileUtil" module to their own module
+"File::Package" module.
+The module name is now much more descriptive
+of the routines in the module.
+
+=item File-Package-0.02
+
+Replace the obsolete "File::FileUtil" with File::Packgage
+in the test script "t\File\package.t".
+
+=item File-Package-0.05
+
+Added subroutine interfaces.
+
+Added @import input to load_packages method
+
 =back
 
 =head2 3.4 Adaptation data.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -450,8 +458,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-Package-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.02
+   http://www.softwarediamonds/packages/File-Package-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.03
 
 
 =item Prerequistes.
@@ -530,7 +538,13 @@ Plain Old Documentation
 
 =head1 2.0 SEE ALSO
 
+=over 4
 
+=item L<File::Package|File::Package> 
+
+=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+=back
 
 =for html
 <hr>
@@ -555,13 +569,12 @@ Plain Old Documentation
 __DATA__
 
 DISTNAME: File-Package^
-VERSION : 0.02^
-REPOSITORY_DIR: packages^
+VERSION : 0.03^
 FREEZE: 1^
-
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: B^
+
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Generic file utilities originally developed to support Test::STDmaker^
 TITLE   :  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker^
@@ -571,7 +584,7 @@ CLASSIFICATION: NONE^
 TEMPLATE:  ^
 CSS: help.css^
 SVD_FSPEC: Unix^
-
+REPOSITORY_DIR: packages^
 REPOSITORY: 
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
@@ -589,6 +602,8 @@ return if $file =~ s=t/File/FileUtil/FileUtil.t=t/File/package.t=;
 AUTO_REVISE: 
 lib/File/Package.pm
 t/File/package.t
+t/File/BadLoad.pm
+t/File/BadVocab.pm
 ^
 
 PREREQ_PM:  ^
@@ -596,22 +611,16 @@ TESTS: t/File/package.t^
 EXE_FILES:  ^
 
 CHANGES:
-Removed the methods for loading a
-program module with the same name 
-from the "File::FileUtil" module to their own module
-"File::Package" module.
-The module name is now much more descriptive
-of the routines in the module.
 
 Changes to past revisions are as follows: 
 
 \=over 4
 
-\=item Test::TestUtil 0.01
+\=item Test-TestUtil-0.01
 
 Originated
 
-\=item Test::TestUtil 0.02
+\=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -636,7 +645,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-\=item Test::TestUtil 0.03
+\=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -666,7 +675,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-\=item Test::TestUtil 0.04
+\=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -731,7 +740,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-\=item File::FileUtil 0.01
+\=item File-FileUtil-0.01
 
 \=over 4
 
@@ -786,11 +795,11 @@ failure from CPAN testing whose is running on a different platform.
 
 \=back
 
-\=item File::FileUtil 0.02
+\=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-\=item File::FileUtil 0.03
+\=item File-FileUtil-0.03
 
 \=over 4
 
@@ -809,6 +818,26 @@ the directories in @INC
 
 \=back
 
+\=item File-Package-0.01
+
+Removed the methods for loading a
+program module with the same name 
+from the "File::FileUtil" module to their own module
+"File::Package" module.
+The module name is now much more descriptive
+of the routines in the module.
+
+\=item File-Package-0.02
+
+Replace the obsolete "File::FileUtil" with File::Packgage
+in the test script "t\File\package.t".
+
+\=item File-Package-0.05
+
+Added subroutine interfaces.
+
+Added @import input to load_packages method
+
 \=back
 
 ^
@@ -949,7 +978,16 @@ Plain Old Documentation
 \=back
 ^
 
-SEE_ALSO:  ^
+SEE_ALSO: 
+\=over 4
+
+\=item L<File::Package|File::Package> 
+
+\=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+\=back
+^
+
 
 HTML:
 <hr>
